# unitorch.cli.models.vit

## ViTProcessor

!!! tip
    **`core/process/vit`** is the section for configuration of ViTProcessor.

::: unitorch.cli.models.vit.ViTProcessor

## ViTForImageClassification

!!! tip
    **`core/model/classification/vit`** is the section for configuration of ViTForImageClassification.

::: unitorch.cli.models.vit.ViTForImageClassification
